@@ -74,7 +74,7 @@ through a number of states:
 
 =item 1. Creation
 
-The first thing in the life of a coro thread is it's creation -
+The first thing in the life of a coro thread is its creation -
 obviously. The typical way to create a thread is to call the C<async
 BLOCK> function:
 
@@ -93,7 +93,7 @@ it will run as soon as the CPU is free for it.
 
 C<async> will return a Coro object - you can store this for future
 reference or ignore it - a thread that is running, ready to run or waiting
-for some event is alive on it's own.
+for some event is alive on its own.
 
 Another way to create a thread is to call the C<new> constructor with a
 code-reference:
@@ -250,7 +250,7 @@ since the thread object returned by C<async> is not stored anywhere, the
 thread is initially referenced because it is in the ready queue, when it
 runs it is referenced by C<$Coro::current>, but when it calls C<schedule>,
 it gets C<cancel>ed causing the guard object to be destroyed (see the next
-section), and printing it's message.
+section), and printing its message.
 
 If this seems a bit drastic, remember that this only happens when nothing
 references the thread anymore, which means there is no way to further
@@ -263,7 +263,7 @@ Threads will allocate various resources. Most but not all will be returned
 when a thread terminates, during clean-up.
 
 Cleanup is quite similar to throwing an uncaught exception: perl will
-work it's way up through all subroutine calls and blocks. On it's way, it
+work its way up through all subroutine calls and blocks. On its way, it
 will release all C<my> variables, undo all C<local>'s and free any other
 resources truly local to the thread.
 
@@ -295,7 +295,7 @@ code blocks):
    async {
       my $window = new Gtk2::Window "toplevel";
       # The window will not be cleaned up automatically, even when $window
-      # gets freed, so use a guard to ensure it's destruction
+      # gets freed, so use a guard to ensure its destruction
       # in case of an error:
       my $window_guard = Guard::guard { $window->destroy };
 
@@ -368,7 +368,7 @@ our $idle;    # idle handler
 our $main;    # main coro
 our $current; # current coro
 
-our $VERSION = 6.53;
+our $VERSION = 6.57;
 
 our @EXPORT = qw(async async_pool cede schedule terminate current unblock_sub rouse_cb rouse_wait);
 our %EXPORT_TAGS = (
@@ -761,7 +761,7 @@ automatically get assigned a perl interpreter when they are transferred to.
 =item $state->is_zombie
 
 Returns true iff the Coro object has been cancelled, i.e.
-it's resources freed because they were C<cancel>'ed, C<terminate>'d,
+its resources freed because they were C<cancel>'ed, C<terminate>'d,
 C<safe_cancel>'ed or simply went out of scope.
 
 The name "zombie" stems from UNIX culture, where a process that has
@@ -921,7 +921,7 @@ return once the C<$coro> terminates.
 =item $coro->on_destroy (\&cb)
 
 Registers a callback that is called when this coro thread gets destroyed,
-that is, after it's resources have been freed but before it is joined. The
+that is, after its resources have been freed but before it is joined. The
 callback gets passed the terminate/cancel arguments, if any, and I<must
 not> die, under any circumstances.
 
@@ -1087,12 +1087,15 @@ Create and return a "rouse callback". That's a code reference that,
 when called, will remember a copy of its arguments and notify the owner
 coro of the callback.
 
-See the next function.
+Only the first invocation will store agruments and signal any waiter -
+further calls will effectively be ignored, but it is ok to try.
+
+Also see the next function.
 
 =item @args = rouse_wait [$cb]
 
-Wait for the specified rouse callback (or the last one that was created in
-this coro).
+Wait for the specified rouse callback to be invoked (or if the argument is
+missing, use the most recently created callback in the current coro).
 
 As soon as the callback is invoked (or when the callback was invoked
 before C<rouse_wait>), it will return the arguments originally passed to
@@ -1100,8 +1103,13 @@ the rouse callback. In scalar context, that means you get the I<last>
 argument, just as if C<rouse_wait> had a C<return ($a1, $a2, $a3...)>
 statement at the end.
 
+You are only allowed to wait once for a given rouse callback.
+
 See the section B<HOW TO WAIT FOR A CALLBACK> for an actual usage example.
 
+As of Coro 6.57, you can reliably wait for a rouse callback in a different
+thread than from where it was created.
+
 =back
 
 =cut
@@ -1116,7 +1124,7 @@ for my $module (qw(Channel RWLock Semaphore SemaphoreSet Signal Specific)) {
       *{"Coro::$module\::new"} = $old
          if $old;
 
-      goto &{"Coro::$module\::new"};
+      goto &{"Coro::$module\::new"}
    };
 }
 
