@@ -13,9 +13,19 @@ Coro::RWLock - reader/write locks
 
  # or:
  $lck->wrlock; # acquire write lock
- $lck->tryrdlock; # try a readlock
- $lck->trywrlock; # try a write lock
+ $lck->unlock; # unlock lock again
 
+ # try a readlock
+ if ($lck->tryrdlock) {
+    ...;
+    $l->unlock;
+ }
+
+ # try a write lock
+ if ($lck->trywrlock) {
+    ...;
+    $l->unlock;
+ }
 
 =head1 DESCRIPTION
 
@@ -25,8 +35,8 @@ read by many coroutines in parallel as long as no writer has locked it
 exist. RWLocks basically allow many concurrent readers (without writers)
 OR a single writer (but no readers).
 
-You don't have to load C<Coro::RWLock> manually, it will be loaded 
-automatically when you C<use Coro> and call the C<new> constructor. 
+You don't have to load C<Coro::RWLock> manually, it will be loaded
+automatically when you C<use Coro> and call the C<new> constructor.
 
 =over 4
 
@@ -38,7 +48,7 @@ use common::sense;
 
 use Coro ();
 
-our $VERSION = 6.53;
+our $VERSION = 6.57;
 
 =item $l = new Coro::RWLock;
 
@@ -47,7 +57,7 @@ Create a new reader/writer lock.
 =cut
 
 sub new {
-   # [rdcount, [readqueue], wrcount, [writequeue]]
+   # [wrcount, [wrqueue], rdcount, [rdqueue]]
    bless [0, [], 0, []], $_[0];
 }
 
@@ -103,6 +113,8 @@ Give up a previous C<rdlock> or C<wrlock>.
 
 =cut
 
+my $waiter;
+
 sub unlock {
    # either we are a reader or a writer. decrement accordingly.
    if ($_[0][2]) {
@@ -110,11 +122,12 @@ sub unlock {
    } else {
       $_[0][0]--;
    }
-   # now we have the choice between waking up a reader or a writer. we choose the writer.
+   # now we have the choice between waking up a writer or all readers. we choose the writer.
    if (@{$_[0][1]}) {
       (shift @{$_[0][1]})->ready;
-   } elsif (@{$_[0][3]}) {
-      (shift @{$_[0][3]})->ready;
+   } else {
+      $waiter->ready
+         while $waiter = shift @{$_[0][3]};
    }
 }
 
