@@ -93,7 +93,7 @@ sub warnhook { &$WARNHOOK }
 use XSLoader;
 
 BEGIN {
-   our $VERSION = 6.53;
+   our $VERSION = 6.57;
 
    # must be done here because the xs part expects it to exist
    # it might exist already because Coro::Specific created it.
@@ -293,11 +293,11 @@ swap a hash with a reference (i.e. C<%hash> I<becomes> a reference), and perl
 will not like this at all.
 
 It will also swap "magicalness" - so when swapping a builtin perl variable
-(such as C<$.>), it will lose it's magicalness, which, again, perl will
+(such as C<$.>), it will lose its magicalness, which, again, perl will
 not like, so don't do it.
 
 Lastly, the C<$swap_sv> itself will be used, not a copy, so make sure you
-give each thread it's own C<$swap_sv> instance.
+give each thread its own C<$swap_sv> instance.
 
 It is, however, quite safe to swap some normal variable with
 another. For example, L<PApp::SQL> stores the default database handle in
